*******************
Authors and Credits
*******************

PlasmaPy Coordinating Committee
===============================

* :user:`Erik Everson <rocco8773>`
* :user:`Nicholas Murphy <namurphy>`
* :user:`Dominik Stańczak-Marikin <StanczakDominik>`

PlasmaPy Contributors
=====================

.. This list contains contributors to the core package as well as to the
   vision statement when it was originally hosted on Google Docs.  Some
   of the people who made commits do not show up as contributors on the
   GitHub page, so it is important to check the git log as well to make
   sure we are not missing anyone.

The people in the following list have contributed to PlasmaPy. Included
in parentheses are `ORCID author identifiers <https://orcid.org>`__.

.. include:: _authors.rst

.. ORCID provides a unique persistent identifier that you own and control.
   To sign up, please go to: https://orcid.org/register

This list contains contributors to PlasmaPy's core package and vision
statement, including a few people who do not show up as `PlasmaPy
contributors on GitHub
<https://github.com/PlasmaPy/PlasmaPy/graphs/contributors>`__.  If you made
a contribution to PlasmaPy that was merged and your name is missing from
the list, your information is incorrect, or you do not wish to be
listed, then please submit a pull request.

Other Credits
=============

The PlasmaPy Community thanks the SunPy and Astropy communities for
inspiring this project in the first place, providing much helpful
advice, and showing examples of how to build a community-wide open
source scientific software package. The PlasmaPy Community also thanks
the Python in Heliophysics Community.

Acknowledgements
================

Early development on PlasmaPy was partially supported by the U.S.
Department of Energy through grant DE-SC0016363 that was funded through
the NSF-DOE Partnership on Basic Plasma Science and Engineering; a
Scholarly Studies grant awarded by the Smithsonian Institution; Google
Summer of Code; and NASA Heliophysics Data Environment Enhancements
(HDEE) grant 80NSSC20K0174. PlasmaPy is being developed with support
from the U.S. National Science Foundation through grants 1931388,
1931393, 1931429, and 1931435 that were awarded through `a collaborative
proposal
<https://doi.org/10.5281/zenodo.3406803>`__ submitted to the
Cyberinfrastructure for Sustained Scientific Innovation (CSSI) program.

All opinions, findings, conclusions, and recommendations expressed in
this material are those of the authors and do not necessarily reflect
the views of any of the funding agencies or organizations that have
supported PlasmaPy development.
